@@ -3,14 +3,15 @@ __author__ = 'ninja'
 """ This is a sample piece of code written as part
     of the head first python text """
 
-def print_lol(the_list, level=0):
+def print_lol(the_list, indent=False, level=0):
     """ this is the function that takes each member of a list
         and checks if the member is a list itself. It recursively prints
         out all the individual members of the nested lists """
     for each_item in the_list:
         if isinstance(each_item, list):
-            print_lol(each_item, level + 1)
+            print_lol(each_item, indent, level + 1)
         else:
-            for tab_stop in range(level):
-                print("\t", end=' ')
+            if indent:
+                for tab_stop in range(level):
+                    print("\t", end=' ')
             print(each_item)
